@@ -1,5 +1,5 @@
-from dir2 import file2
-from dir3.file3 import double, VALUE_2
+from another_example_pkg_ralcanta.dir2 import file2
+from another_example_pkg_ralcanta.dir3.file3 import double, VALUE_2
 
 def test(arr):
     print("Printing sum form file2:")
